@@ -1,4 +1,10 @@
-"""Showcases *ATD (1995)* colour appearance model computations."""
+"""
+Demonstrate *ATD (1995)* colour appearance model computations.
+
+This module provides examples of colour appearance model computations using the
+*ATD (1995)* model, illustrating forward transformation from tristimulus values
+to colour appearance correlates and reference specification broadcasting.
+"""
 
 import numpy as np
 
@@ -6,7 +12,7 @@ import colour
 from colour.appearance.atd95 import CAM_ReferenceSpecification_ATD95
 from colour.utilities import message_box
 
-message_box('"ATD (1995)" Colour Appearance Model Computations')
+message_box('Compute "ATD (1995)" Colour Appearance Model Correlates')
 
 XYZ = np.array([19.01, 20.00, 21.78])
 XYZ_0 = np.array([95.05, 100.00, 108.88])
@@ -14,7 +20,7 @@ Y_0 = 318.31
 k_1 = 0.0
 k_2 = 50.0
 message_box(
-    f'Converting to the "ATD (1995)" colour appearance model specification '
+    f'Convert to the "ATD (1995)" colour appearance model specification '
     f"using given parameters:\n\n"
     f"\tXYZ: {XYZ}\n"
     f"\tXYZ_0: {XYZ_0}\n"
@@ -28,7 +34,7 @@ print(specification)
 print("\n")
 
 message_box(
-    'Broadcasting the current output "ATD (1995)" colour appearance '
+    'Broadcast the current output "ATD (1995)" colour appearance '
     "model specification to the reference specification.\n"
     "The intent of this reference specification is to provide names "
     'as closest as possible to the "Mark D. Fairchild" reference.\n'
