@@ -25,26 +25,29 @@ References
 
 from __future__ import annotations
 
+import typing
 from copy import deepcopy
 
 import numpy as np
 
 from colour.adaptation import matrix_chromatic_adaptation_VonKries
 from colour.algebra import vecmul
-from colour.hints import (
-    Any,
-    ArrayLike,
-    Callable,
-    LiteralChromaticAdaptationTransform,
-    LiteralRGBColourspace,
-    NDArrayFloat,
-    cast,
-)
+
+if typing.TYPE_CHECKING:
+    from colour.hints import (
+        Any,
+        ArrayLike,
+        Callable,
+        Domain1,
+        LiteralChromaticAdaptationTransform,
+        LiteralRGBColourspace,
+        NDArrayFloat,
+        Range1,
+    )
+
+from colour.hints import cast
 from colour.models import xy_to_xyY, xy_to_XYZ, xyY_to_XYZ
-from colour.models.rgb import (
-    chromatically_adapted_primaries,
-    normalised_primary_matrix,
-)
+from colour.models.rgb import chromatically_adapted_primaries, normalised_primary_matrix
 from colour.utilities import (
     as_float_array,
     attest,
@@ -77,53 +80,52 @@ __all__ = [
 
 class RGB_Colourspace:
     """
-    Implement support for the *RGB* colourspaces datasets from
-    :mod:`colour.models.datasets.aces_rgb`, etc....
+    Implement support for *RGB* colourspace datasets from modules including
+    :mod:`colour.models.datasets.aces_rgb`.
 
     Colour science literature related to *RGB* colourspaces and encodings
-    defines their dataset using different degree of precision or rounding.
-    While instances where a whitepoint is being defined with a value
-    different from its canonical agreed one are rare, it is however very
-    common to have normalised primary matrices rounded at different
-    decimals. This can yield large discrepancies in computations.
+    defines datasets using different degrees of precision or rounding. While
+    instances where a whitepoint differs from its canonical agreed value are
+    rare, normalised primary matrices are commonly rounded at different
+    decimal places. This can yield large discrepancies in computations.
 
-    Such an occurrence is the *V-Gamut* colourspace white paper, that defines
-    the *V-Gamut* to *ITU-R BT.709* conversion matrix as follows::
+    Such an occurrence is the *V-Gamut* colourspace white paper, which
+    defines the *V-Gamut* to *ITU-R BT.709* conversion matrix as follows::
 
         [[ 1.806576 -0.695697 -0.110879]
          [-0.170090  1.305955 -0.135865]
          [-0.025206 -0.154468  1.179674]]
 
-    Computing this matrix using *ITU-R BT.709* colourspace derived normalised
-    primary matrix yields::
+    Computing this matrix using *ITU-R BT.709* colourspace derived
+    normalised primary matrix yields::
 
         [[ 1.8065736 -0.6956981 -0.1108786]
          [-0.1700890  1.3059548 -0.1358648]
          [-0.0252057 -0.1544678  1.1796737]]
 
-    The latter matrix is almost equals with the former, however performing the
-    same computation using *IEC 61966-2-1:1999* *sRGB* colourspace normalised
-    primary matrix introduces severe disparities::
+    The latter matrix is almost equal to the former, however performing the
+    same computation using *IEC 61966-2-1:1999* *sRGB* colourspace
+    normalised primary matrix introduces severe disparities::
 
         [[ 1.8063853 -0.6956147 -0.1109453]
          [-0.1699311  1.3058387 -0.1358616]
          [-0.0251630 -0.1544899  1.1797117]]
 
-    In order to provide support for both literature defined dataset and
-    accurate computations enabling transformations without loss of precision,
-    the :class:`colour.RGB_Colourspace` class provides two sets of
-    transformation matrices:
+    To provide support for both literature-defined datasets and accurate
+    computations enabling transformations without loss of precision, the
+    :class:`colour.RGB_Colourspace` class provides two sets of transformation
+    matrices:
 
         -   Instantiation transformation matrices
         -   Derived transformation matrices
 
     Upon instantiation, the :class:`colour.RGB_Colourspace` class stores the
-    given ``matrix_RGB_to_XYZ`` and ``matrix_XYZ_to_RGB`` arguments and also
-    computes their derived counterpart using the ``primaries`` and
+    specified ``matrix_RGB_to_XYZ`` and ``matrix_XYZ_to_RGB`` arguments and
+    also computes their derived counterparts using the ``primaries`` and
     ``whitepoint`` arguments.
 
-    Whether the initialisation or derived matrices are used in subsequent
-    computations is dependent on the
+    Whether instantiation or derived matrices are used in subsequent
+    computations depends on the
     :attr:`colour.RGB_Colourspace.use_derived_matrix_RGB_to_XYZ` and
     :attr:`colour.RGB_Colourspace.use_derived_matrix_XYZ_to_RGB` attribute
     values.
@@ -139,14 +141,16 @@ class RGB_Colourspace:
     whitepoint_name
         *RGB* colourspace whitepoint name.
     matrix_RGB_to_XYZ
-        Transformation matrix from colourspace to *CIE XYZ* tristimulus values.
+        Transformation matrix from colourspace to *CIE XYZ* tristimulus
+        values.
     matrix_XYZ_to_RGB
-        Transformation matrix from *CIE XYZ* tristimulus values to colourspace.
+        Transformation matrix from *CIE XYZ* tristimulus values to
+        colourspace.
     cctf_encoding
         Encoding colour component transfer function (Encoding CCTF) /
         opto-electronic transfer function (OETF) that maps estimated
-        tristimulus values in a scene to :math:`R'G'B'` video component signal
-        value.
+        tristimulus values in a scene to :math:`R'G'B'` video component
+        signal value.
     cctf_decoding
         Decoding colour component transfer function (Decoding CCTF) /
         electro-optical transfer function (EOTF) that maps an
@@ -157,7 +161,8 @@ class RGB_Colourspace:
         use a computed derived normalised primary matrix.
     use_derived_matrix_XYZ_to_RGB
         Whether to use the instantiation time inverse normalised primary
-        matrix or to use a computed derived inverse normalised primary matrix.
+        matrix or to use a computed derived inverse normalised primary
+        matrix.
 
     Attributes
     ----------
@@ -186,10 +191,10 @@ class RGB_Colourspace:
     -   The normalised primary matrix defined by
         :attr:`colour.RGB_Colourspace.matrix_RGB_to_XYZ` property is treated
         as the prime matrix from which the inverse will be calculated as
-        required by the internal derivation mechanism. This behaviour has been
-        chosen in accordance with literature where commonly a *RGB* colourspace
-        is defined by its normalised primary matrix as it is directly computed
-        from the chosen primaries and whitepoint.
+        required by the internal derivation mechanism. This behaviour has
+        been chosen in accordance with literature where commonly a *RGB*
+        colourspace is defined by its normalised primary matrix as it is
+        directly computed from the chosen primaries and whitepoint.
 
     References
     ----------
@@ -279,7 +284,7 @@ class RGB_Colourspace:
     @property
     def name(self) -> str:
         """
-        Getter and setter property for the name.
+        Getter and setter for the *RGB* colourspace name.
 
         Parameters
         ----------
@@ -295,7 +300,7 @@ class RGB_Colourspace:
         return self._name
 
     @name.setter
-    def name(self, value: str):
+    def name(self, value: str) -> None:
         """Setter for the **self.name** property."""
 
         attest(
@@ -308,7 +313,7 @@ class RGB_Colourspace:
     @property
     def primaries(self) -> NDArrayFloat:
         """
-        Getter and setter property for the primaries.
+        Getter and setter for the *RGB* colourspace primaries.
 
         Parameters
         ----------
@@ -324,12 +329,12 @@ class RGB_Colourspace:
         return self._primaries
 
     @primaries.setter
-    def primaries(self, value: ArrayLike):
+    def primaries(self, value: ArrayLike) -> None:
         """Setter for the **self.primaries** property."""
 
         attest(
             isinstance(value, (tuple, list, np.ndarray, np.matrix)),
-            f'"matrix_XYZ_to_RGB" property: "{value!r}" is not a "tuple", '
+            f'"primaries" property: "{value!r}" is not a "tuple", '
             f'"list", "ndarray" or "matrix" instance!',
         )
 
@@ -345,7 +350,7 @@ class RGB_Colourspace:
     @property
     def whitepoint(self) -> NDArrayFloat:
         """
-        Getter and setter property for the whitepoint.
+        Getter and setter for the *RGB* colourspace whitepoint.
 
         Parameters
         ----------
@@ -361,12 +366,12 @@ class RGB_Colourspace:
         return self._whitepoint
 
     @whitepoint.setter
-    def whitepoint(self, value: ArrayLike):
+    def whitepoint(self, value: ArrayLike) -> None:
         """Setter for the **self.whitepoint** property."""
 
         attest(
             isinstance(value, (tuple, list, np.ndarray, np.matrix)),
-            f'"matrix_XYZ_to_RGB" property: "{value!r}" is not a "tuple", '
+            f'"whitepoint" property: "{value!r}" is not a "tuple", '
             f'"list", "ndarray" or "matrix" instance!',
         )
 
@@ -379,23 +384,30 @@ class RGB_Colourspace:
     @property
     def whitepoint_name(self) -> str | None:
         """
-        Getter and setter property for the whitepoint_name.
+        Getter and setter for the *RGB* colourspace whitepoint name.
+
+        Define or retrieve the name identifier for the reference illuminant
+        (whitepoint) used by this *RGB* colourspace. This property allows
+        tracking of standardized illuminant names such as 'D65', 'D50', or
+        custom whitepoint identifiers.
 
         Parameters
         ----------
         value
-            Value to set the whitepoint_name with.
+            Name identifier to set for the *RGB* colourspace whitepoint. Can
+            be a standard illuminant name or custom identifier.
 
         Returns
         -------
-        :py:data:`None` or :class:`str`
-            *RGB* colourspace whitepoint name.
+        :class:`str` or :py:data:`None`
+            *RGB* colourspace whitepoint name identifier. Returns
+            :py:data:`None` if no name has been specified.
         """
 
         return self._whitepoint_name
 
     @whitepoint_name.setter
-    def whitepoint_name(self, value: str | None):
+    def whitepoint_name(self, value: str | None) -> None:
         """Setter for the **self.whitepoint_name** property."""
 
         if value is not None:
@@ -409,31 +421,32 @@ class RGB_Colourspace:
     @property
     def matrix_RGB_to_XYZ(self) -> NDArrayFloat:
         """
-        Getter and setter property for the transformation matrix from
-        colourspace to *CIE XYZ* tristimulus values.
+        Getter and setter for the transformation matrix from RGB colourspace
+        to *CIE XYZ* tristimulus values.
 
         Parameters
         ----------
         value
-            Transformation matrix from colourspace to *CIE XYZ* tristimulus
-            values.
+            Transformation matrix from RGB colourspace to *CIE XYZ*
+            tristimulus values.
 
         Returns
         -------
         :class:`numpy.ndarray`
-            Transformation matrix from colourspace to *CIE XYZ* tristimulus
-            values.
+            Transformation matrix from RGB colourspace to *CIE XYZ*
+            tristimulus values.
         """
 
         if self._matrix_RGB_to_XYZ is None or self._use_derived_matrix_RGB_to_XYZ:
             if self._derived_matrix_RGB_to_XYZ.size == 0:
                 self._derive_transformation_matrices()
+
             return self._derived_matrix_RGB_to_XYZ
-        else:
-            return self._matrix_RGB_to_XYZ
+
+        return self._matrix_RGB_to_XYZ
 
     @matrix_RGB_to_XYZ.setter
-    def matrix_RGB_to_XYZ(self, value: ArrayLike | None):
+    def matrix_RGB_to_XYZ(self, value: ArrayLike | None) -> None:
         """Setter for the **self.matrix_RGB_to_XYZ** property."""
 
         if value is not None:
@@ -450,31 +463,32 @@ class RGB_Colourspace:
     @property
     def matrix_XYZ_to_RGB(self) -> NDArrayFloat:
         """
-        Getter and setter property for the transformation matrix from *CIE XYZ*
-        tristimulus values to colourspace.
+        Getter and setter for the transformation matrix from *CIE XYZ*
+        tristimulus values to RGB colourspace.
 
         Parameters
         ----------
         value
-            Transformation matrix from *CIE XYZ* tristimulus values to
+            Transformation matrix from *CIE XYZ* tristimulus values to the
             colourspace.
 
         Returns
         -------
         :class:`numpy.ndarray`
-            Transformation matrix from *CIE XYZ* tristimulus values to
+            Transformation matrix from *CIE XYZ* tristimulus values to the
             colourspace.
         """
 
         if self._matrix_XYZ_to_RGB is None or self._use_derived_matrix_XYZ_to_RGB:
             if self._derived_matrix_XYZ_to_RGB.size == 0:
                 self._derive_transformation_matrices()
+
             return self._derived_matrix_XYZ_to_RGB
-        else:
-            return self._matrix_XYZ_to_RGB
+
+        return self._matrix_XYZ_to_RGB
 
     @matrix_XYZ_to_RGB.setter
-    def matrix_XYZ_to_RGB(self, value: ArrayLike | None):
+    def matrix_XYZ_to_RGB(self, value: ArrayLike | None) -> None:
         """Setter for the **self.matrix_XYZ_to_RGB** property."""
 
         if value is not None:
@@ -491,9 +505,8 @@ class RGB_Colourspace:
     @property
     def cctf_encoding(self) -> Callable | None:
         """
-        Getter and setter property for the encoding colour component transfer
-        function (Encoding CCTF) / opto-electronic transfer function
-        (OETF).
+        Getter and setter for the encoding colour component transfer
+        function (Encoding CCTF) / opto-electronic transfer function (OETF).
 
         Parameters
         ----------
@@ -503,7 +516,7 @@ class RGB_Colourspace:
 
         Returns
         -------
-        :py:data:`None` or Callable
+        Callable or :py:data:`None`
             Encoding colour component transfer function (Encoding CCTF) /
             opto-electronic transfer function (OETF).
         """
@@ -511,7 +524,7 @@ class RGB_Colourspace:
         return self._cctf_encoding
 
     @cctf_encoding.setter
-    def cctf_encoding(self, value: Callable | None):
+    def cctf_encoding(self, value: Callable | None) -> None:
         """Setter for the **self.cctf_encoding** property."""
 
         if value is not None:
@@ -525,7 +538,7 @@ class RGB_Colourspace:
     @property
     def cctf_decoding(self) -> Callable | None:
         """
-        Getter and setter property for the decoding colour component transfer
+        Getter and setter for the decoding colour component transfer
         function (Decoding CCTF) / electro-optical transfer function
         (EOTF).
 
@@ -537,7 +550,7 @@ class RGB_Colourspace:
 
         Returns
         -------
-        :py:data:`None` or Callable
+        Callable or :py:data:`None`
             Decoding colour component transfer function (Decoding CCTF) /
             electro-optical transfer function (EOTF).
         """
@@ -545,7 +558,7 @@ class RGB_Colourspace:
         return self._cctf_decoding
 
     @cctf_decoding.setter
-    def cctf_decoding(self, value: Callable | None):
+    def cctf_decoding(self, value: Callable | None) -> None:
         """Setter for the **self.cctf_decoding** property."""
 
         if value is not None:
@@ -559,9 +572,12 @@ class RGB_Colourspace:
     @property
     def use_derived_matrix_RGB_to_XYZ(self) -> bool:
         """
-        Getter and setter property for whether to use the instantiation time
-        normalised primary matrix or to use a computed derived normalised
-        primary matrix.
+        Getter and setter for whether to use the instantiation time normalised
+        primary matrix or to use a computed derived normalised primary matrix.
+
+        Control whether the RGB to XYZ transformation uses the pre-computed
+        normalised primary matrix from instantiation or derives it dynamically
+        from the current primaries and whitepoint.
 
         Parameters
         ----------
@@ -579,7 +595,7 @@ class RGB_Colourspace:
         return self._use_derived_matrix_RGB_to_XYZ
 
     @use_derived_matrix_RGB_to_XYZ.setter
-    def use_derived_matrix_RGB_to_XYZ(self, value: bool):
+    def use_derived_matrix_RGB_to_XYZ(self, value: bool) -> None:
         """Setter for the **self.use_derived_matrix_RGB_to_XYZ** property."""
 
         attest(
@@ -592,29 +608,31 @@ class RGB_Colourspace:
     @property
     def use_derived_matrix_XYZ_to_RGB(self) -> bool:
         """
-        Getter and setter property for Whether to use the instantiation time
-        inverse normalised primary matrix or to use a computed derived inverse
-        normalised primary matrix.
+        Getter and setter for whether to use the instantiation time inverse
+        normalised primary matrix or to compute a derived inverse normalised
+        primary matrix.
+
+        Control whether the XYZ to RGB transformation uses the pre-computed
+        inverse matrix from instantiation or derives it dynamically from the
+        current primary matrix.
 
         Parameters
         ----------
         value
             Whether to use the instantiation time inverse normalised primary
-            matrix or to use a computed derived inverse normalised primary
-            matrix.
+            matrix or to compute a derived inverse normalised primary matrix.
 
         Returns
         -------
         :class:`bool`
             Whether to use the instantiation time inverse normalised primary
-            matrix or to use a computed derived inverse normalised primary
-            matrix.
+            matrix or to compute a derived inverse normalised primary matrix.
         """
 
         return self._use_derived_matrix_XYZ_to_RGB
 
     @use_derived_matrix_XYZ_to_RGB.setter
-    def use_derived_matrix_XYZ_to_RGB(self, value: bool):
+    def use_derived_matrix_XYZ_to_RGB(self, value: bool) -> None:
         """Setter for the **self.use_derived_matrix_XYZ_to_RGB** property."""
 
         attest(
@@ -626,12 +644,14 @@ class RGB_Colourspace:
 
     def __str__(self) -> str:
         """
-        Return a formatted string representation of the *RGB* colourspace.
+        Generate a formatted string representation of the *RGB* colourspace.
 
         Returns
         -------
         :class:`str`
-            Formatted string representation.
+            Formatted string representation displaying colourspace properties
+            including primaries, whitepoint, encoding/decoding CCTFs, and
+            normalised primary matrices.
 
         Examples
         --------
@@ -689,6 +709,7 @@ class RGB_Colourspace:
         """
         if self._derived_matrix_XYZ_to_RGB.size == 0:
             self._derive_transformation_matrices()
+
         return multiline_str(
             self,
             [
@@ -722,13 +743,15 @@ class RGB_Colourspace:
 
     def __repr__(self) -> str:
         """
-        Return an (almost) evaluable string representation of the *RGB*
-        colourspace.
+        Return an evaluable string representation of the *RGB* colourspace.
+
+        The representation includes all parameters needed to reconstruct the
+        colourspace instance.
 
         Returns
         -------
-        :class`str`
-            (Almost) evaluable string representation.
+        :class:`str`
+            Evaluable string representation.
 
         Examples
         --------
@@ -804,10 +827,13 @@ class RGB_Colourspace:
             ],
         )
 
-    def _derive_transformation_matrices(self):
+    def _derive_transformation_matrices(self) -> None:
         """
-        Compute the derived transformations matrices, the normalised primary
-        matrix and its inverse.
+        Derive transformation matrices from the RGB colourspace specification.
+
+        Compute the normalised primary matrix and its inverse matrix that are
+        used for transformations between the RGB colourspace and CIE XYZ
+        tristimulus values.
         """
 
         if self._primaries is not None and self._whitepoint is not None:
@@ -816,16 +842,16 @@ class RGB_Colourspace:
             self._derived_matrix_RGB_to_XYZ = npm
             self._derived_matrix_XYZ_to_RGB = np.linalg.inv(npm)
 
-    def use_derived_transformation_matrices(self, usage: bool = True):
+    def use_derived_transformation_matrices(self, usage: bool = True) -> None:
         """
-        Enable or disables usage of both derived transformations matrices,
+        Enable or disable usage of both derived transformation matrices,
         the normalised primary matrix and its inverse in subsequent
         computations.
 
         Parameters
         ----------
         usage
-            Whether to use the derived transformations matrices.
+            Whether to use the derived transformation matrices.
         """
 
         self.use_derived_matrix_RGB_to_XYZ = usage
@@ -841,8 +867,8 @@ class RGB_Colourspace:
     ) -> RGB_Colourspace:
         """
         Chromatically adapt the *RGB* colourspace *primaries* :math:`xy`
-        chromaticity coordinates from *RGB* colourspace whitepoint to reference
-        ``whitepoint``.
+        chromaticity coordinates from *RGB* colourspace whitepoint to the
+        specified reference whitepoint.
 
         Parameters
         ----------
@@ -900,33 +926,37 @@ class RGB_Colourspace:
         colourspace.whitepoint = whitepoint
         colourspace.whitepoint_name = whitepoint_name
 
-        colourspace._matrix_RGB_to_XYZ = None
-        colourspace._matrix_XYZ_to_RGB = None
-        colourspace._derive_transformation_matrices()
+        colourspace._matrix_RGB_to_XYZ = None  # noqa: SLF001
+        colourspace._matrix_XYZ_to_RGB = None  # noqa: SLF001
+        colourspace._derive_transformation_matrices()  # noqa: SLF001
         colourspace.use_derived_transformation_matrices()
 
         colourspace.name = (
             f"{colourspace.name} - Chromatically Adapted to "
-            f"{cast(str, optional(whitepoint_name, whitepoint))!r}"
+            f"{cast('str', optional(whitepoint_name, whitepoint))!r}"
         )
 
         return colourspace
 
     def copy(self) -> RGB_Colourspace:
         """
-        Return a copy of the *RGB* colourspace.
+        Create a deep copy of the *RGB* colourspace instance.
+
+        Generate an independent copy of this *RGB* colourspace with all
+        attributes duplicated, including primaries, whitepoint, matrices,
+        and transfer functions.
 
         Returns
         -------
         :class:`colour.RGB_Colourspace`
-            *RGB* colourspace copy.
+            Independent deep copy of the *RGB* colourspace instance.
         """
 
         return deepcopy(self)
 
 
 def XYZ_to_RGB(
-    XYZ: ArrayLike,
+    XYZ: Domain1,
     colourspace: RGB_Colourspace | LiteralRGBColourspace | str,
     illuminant: ArrayLike | None = None,
     chromatic_adaptation_transform: (
@@ -935,7 +965,7 @@ def XYZ_to_RGB(
     apply_cctf_encoding: bool = False,
     *args: Any,
     **kwargs: Any,
-) -> NDArrayFloat:
+) -> Range1:
     """
     Convert from *CIE XYZ* tristimulus values to *RGB* colourspace array.
 
@@ -946,11 +976,11 @@ def XYZ_to_RGB(
     colourspace
         Output *RGB* colourspace.
     illuminant
-        *CIE xy* chromaticity coordinates or *CIE xyY* colourspace array of the
-        *illuminant* for the input *CIE XYZ* tristimulus values.
+        *CIE xy* chromaticity coordinates or *CIE xyY* colourspace array of
+        the *illuminant* for the input *CIE XYZ* tristimulus values.
     chromatic_adaptation_transform
-        *Chromatic adaptation* transform, if *None* no chromatic adaptation is
-        performed.
+        *Chromatic adaptation* transform. If *None*, no chromatic adaptation
+        is performed.
     apply_cctf_encoding
         Apply the *RGB* colourspace encoding colour component transfer
         function / opto-electronic transfer function.
@@ -972,17 +1002,17 @@ def XYZ_to_RGB(
     +--------------------+-----------------------+---------------+
     | **Domain**         | **Scale - Reference** | **Scale - 1** |
     +====================+=======================+===============+
-    | ``XYZ``            | [0, 1]                | [0, 1]        |
+    | ``XYZ``            | 1                     | 1             |
     +--------------------+-----------------------+---------------+
-    | ``illuminant_XYZ`` | [0, 1]                | [0, 1]        |
+    | ``illuminant_XYZ`` | 1                     | 1             |
     +--------------------+-----------------------+---------------+
-    | ``illuminant_RGB`` | [0, 1]                | [0, 1]        |
+    | ``illuminant_RGB`` | 1                     | 1             |
     +--------------------+-----------------------+---------------+
 
     +--------------------+-----------------------+---------------+
     | **Range**          | **Scale - Reference** | **Scale - 1** |
     +====================+=======================+===============+
-    | ``RGB``            | [0, 1]                | [0, 1]        |
+    | ``RGB``            | 1                     | 1             |
     +--------------------+-----------------------+---------------+
 
     Examples
@@ -998,7 +1028,7 @@ def XYZ_to_RGB(
     array([ 0.4559528...,  0.0304078...,  0.0408731...])
     """
 
-    from colour.models import RGB_COLOURSPACES
+    from colour.models import RGB_COLOURSPACES  # noqa: PLC0415
 
     XYZ = to_domain_1(XYZ)
 
@@ -1060,18 +1090,18 @@ def XYZ_to_RGB(
 
 
 def RGB_to_XYZ(
-    RGB: ArrayLike,
+    RGB: Domain1,
     colourspace: RGB_Colourspace | LiteralRGBColourspace | str,
     illuminant: ArrayLike | None = None,
     chromatic_adaptation_transform: (
         LiteralChromaticAdaptationTransform | str | None
     ) = "CAT02",
     apply_cctf_decoding: bool = False,
-    *args,
-    **kwargs,
-) -> NDArrayFloat:
+    *args: Any,
+    **kwargs: Any,
+) -> Range1:
     """
-    Convert given *RGB* colourspace array to *CIE XYZ* tristimulus values.
+    Convert specified *RGB* colourspace array to *CIE XYZ* tristimulus values.
 
     Parameters
     ----------
@@ -1080,11 +1110,11 @@ def RGB_to_XYZ(
     colourspace
         Input *RGB* colourspace.
     illuminant
-        *CIE xy* chromaticity coordinates or *CIE xyY* colourspace array of the
-        *illuminant* for the output *CIE XYZ* tristimulus values.
+        *CIE xy* chromaticity coordinates or *CIE xyY* colourspace array of
+        the *illuminant* for the output *CIE XYZ* tristimulus values.
     chromatic_adaptation_transform
-        *Chromatic adaptation* transform, if *None* no chromatic adaptation is
-        performed.
+        *Chromatic adaptation* transform, if *None* no chromatic adaptation
+        is performed.
     apply_cctf_decoding
         Apply the *RGB* colourspace decoding colour component transfer
         function / opto-electronic transfer function.
@@ -1106,17 +1136,17 @@ def RGB_to_XYZ(
     +--------------------+-----------------------+---------------+
     | **Domain**         | **Scale - Reference** | **Scale - 1** |
     +====================+=======================+===============+
-    | ``RGB``            | [0, 1]                | [0, 1]        |
+    | ``RGB``            | 1                     | 1             |
     +--------------------+-----------------------+---------------+
-    | ``illuminant_XYZ`` | [0, 1]                | [0, 1]        |
+    | ``illuminant_XYZ`` | 1                     | 1             |
     +--------------------+-----------------------+---------------+
-    | ``illuminant_RGB`` | [0, 1]                | [0, 1]        |
+    | ``illuminant_RGB`` | 1                     | 1             |
     +--------------------+-----------------------+---------------+
 
     +--------------------+-----------------------+---------------+
     | **Range**          | **Scale - Reference** | **Scale - 1** |
     +====================+=======================+===============+
-    | ``XYZ``            | [0, 1]                | [0, 1]        |
+    | ``XYZ``            | 1                     | 1             |
     +--------------------+-----------------------+---------------+
 
     Examples
@@ -1132,7 +1162,7 @@ def RGB_to_XYZ(
     array([ 0.2163881...,  0.1257    ,  0.0384749...])
     """
 
-    from colour.models import RGB_COLOURSPACES
+    from colour.models import RGB_COLOURSPACES  # noqa: PLC0415
 
     RGB = to_domain_1(RGB)
 
@@ -1201,9 +1231,9 @@ def matrix_RGB_to_RGB(
     ) = "CAT02",
 ) -> NDArrayFloat:
     """
-    Compute the matrix :math:`M` converting from given input *RGB*
-    colourspace to output *RGB* colourspace using given *chromatic
-    adaptation* method.
+    Compute the matrix :math:`M` converting from the specified input *RGB*
+    colourspace to the specified output *RGB* colourspace using the
+    specified *chromatic adaptation* method.
 
     Parameters
     ----------
@@ -1212,8 +1242,8 @@ def matrix_RGB_to_RGB(
     output_colourspace
         *RGB* output colourspace.
     chromatic_adaptation_transform
-        *Chromatic adaptation* transform, if *None* no chromatic adaptation is
-        performed.
+        *Chromatic adaptation* transform. If *None*, no chromatic
+        adaptation is performed.
 
     Returns
     -------
@@ -1238,7 +1268,7 @@ def matrix_RGB_to_RGB(
            [ 0.0163599...,  0.1066124...,  0.8772485...]])
     """
 
-    from colour.models import RGB_COLOURSPACES
+    from colour.models import RGB_COLOURSPACES  # noqa: PLC0415
 
     if isinstance(input_colourspace, str):
         input_colourspace = validate_method(
@@ -1246,7 +1276,7 @@ def matrix_RGB_to_RGB(
             tuple(RGB_COLOURSPACES),
             '"{0}" "RGB" colourspace is invalid, it must be one of {1}!',
         )
-        input_colourspace = cast(RGB_Colourspace, RGB_COLOURSPACES[input_colourspace])
+        input_colourspace = cast("RGB_Colourspace", RGB_COLOURSPACES[input_colourspace])
 
     if isinstance(output_colourspace, str):
         output_colourspace = validate_method(
@@ -1254,7 +1284,9 @@ def matrix_RGB_to_RGB(
             tuple(RGB_COLOURSPACES),
             '"{0}" "RGB" colourspace is invalid, it must be one of {1}!',
         )
-        output_colourspace = cast(RGB_Colourspace, RGB_COLOURSPACES[output_colourspace])
+        output_colourspace = cast(
+            "RGB_Colourspace", RGB_COLOURSPACES[output_colourspace]
+        )
 
     M = input_colourspace.matrix_RGB_to_XYZ
 
@@ -1267,13 +1299,11 @@ def matrix_RGB_to_RGB(
 
         M = np.matmul(M_CAT, input_colourspace.matrix_RGB_to_XYZ)
 
-    M = np.matmul(output_colourspace.matrix_XYZ_to_RGB, M)
-
-    return M
+    return np.matmul(output_colourspace.matrix_XYZ_to_RGB, M)
 
 
 def RGB_to_RGB(
-    RGB: ArrayLike,
+    RGB: Domain1,
     input_colourspace: RGB_Colourspace | LiteralRGBColourspace | str,
     output_colourspace: RGB_Colourspace | LiteralRGBColourspace | str,
     chromatic_adaptation_transform: (
@@ -1282,10 +1312,11 @@ def RGB_to_RGB(
     apply_cctf_decoding: bool = False,
     apply_cctf_encoding: bool = False,
     **kwargs: Any,
-) -> NDArrayFloat:
+) -> Range1:
     """
-    Convert given *RGB* colourspace array from given input *RGB* colourspace
-    to output *RGB* colourspace using given *chromatic adaptation* method.
+    Convert *RGB* colourspace array from the specified input *RGB* colourspace to
+    specified output *RGB* colourspace using the specified *chromatic adaptation*
+    method.
 
     Parameters
     ----------
@@ -1296,11 +1327,11 @@ def RGB_to_RGB(
     output_colourspace
         *RGB* output colourspace.
     chromatic_adaptation_transform
-        *Chromatic adaptation* transform, if *None* no chromatic adaptation is
-        performed.
+        *Chromatic adaptation* transform, if *None* no chromatic adaptation
+        is performed.
     apply_cctf_decoding
-        Apply the input colourspace decoding colour component transfer function
-        / electro-optical transfer function.
+        Apply the input colourspace decoding colour component transfer
+        function / electro-optical transfer function.
     apply_cctf_encoding
         Apply the output colourspace encoding colour component transfer
         function / opto-electronic transfer function.
@@ -1320,13 +1351,13 @@ def RGB_to_RGB(
     +--------------------+-----------------------+---------------+
     | **Domain**         | **Scale - Reference** | **Scale - 1** |
     +====================+=======================+===============+
-    | ``RGB``            | [0, 1]                | [0, 1]        |
+    | ``RGB``            | 1                     | 1             |
     +--------------------+-----------------------+---------------+
 
     +--------------------+-----------------------+---------------+
     | **Range**          | **Scale - Reference** | **Scale - 1** |
     +====================+=======================+===============+
-    | ``RGB``            | [0, 1]                | [0, 1]        |
+    | ``RGB``            | 1                     | 1             |
     +--------------------+-----------------------+---------------+
 
     Examples
@@ -1344,7 +1375,7 @@ def RGB_to_RGB(
     array([ 0.2568891...,  0.0721446...,  0.0465553...])
     """
 
-    from colour.models import RGB_COLOURSPACES
+    from colour.models import RGB_COLOURSPACES  # noqa: PLC0415
 
     if isinstance(input_colourspace, str):
         input_colourspace = validate_method(
@@ -1352,7 +1383,7 @@ def RGB_to_RGB(
             tuple(RGB_COLOURSPACES),
             '"{0}" "RGB" colourspace is invalid, it must be one of {1}!',
         )
-        input_colourspace = cast(RGB_Colourspace, RGB_COLOURSPACES[input_colourspace])
+        input_colourspace = cast("RGB_Colourspace", RGB_COLOURSPACES[input_colourspace])
 
     if isinstance(output_colourspace, str):
         output_colourspace = validate_method(
@@ -1360,7 +1391,9 @@ def RGB_to_RGB(
             tuple(RGB_COLOURSPACES),
             '"{0}" "RGB" colourspace is invalid, it must be one of {1}!',
         )
-        output_colourspace = cast(RGB_Colourspace, RGB_COLOURSPACES[output_colourspace])
+        output_colourspace = cast(
+            "RGB_Colourspace", RGB_COLOURSPACES[output_colourspace]
+        )
 
     RGB = to_domain_1(RGB)
 
