@@ -1,16 +1,12 @@
-# !/usr/bin/env python
 """Define the unit tests for the :mod:`colour.quality.cqs` module."""
 
-import unittest
+from __future__ import annotations
 
 import numpy as np
 
 from colour.colorimetry import SDS_ILLUMINANTS, SDS_LIGHT_SOURCES
 from colour.constants import TOLERANCE_ABSOLUTE_TESTS
-from colour.quality import (
-    ColourRendering_Specification_CQS,
-    colour_quality_scale,
-)
+from colour.quality import ColourRendering_Specification_CQS, colour_quality_scale
 from colour.quality.cqs import DataColorimetry_VS, DataColourQualityScale_VS
 
 __author__ = "Colour Developers"
@@ -25,45 +21,47 @@ __all__ = [
 ]
 
 
-class TestColourQualityScale(unittest.TestCase):
+class TestColourQualityScale:
     """
     Define :func:`colour.quality.cqs.colour_quality_scale` definition unit
     tests methods.
     """
 
-    def test_colour_quality_scale(self):
+    def test_colour_quality_scale(self) -> None:
         """Test :func:`colour.quality.cqs.colour_quality_scale` definition."""
 
         np.testing.assert_allclose(
-            colour_quality_scale(SDS_ILLUMINANTS["FL1"]),
+            colour_quality_scale(SDS_ILLUMINANTS["FL1"], additional_data=False),
             74.982585798279914,
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
         np.testing.assert_allclose(
             colour_quality_scale(
-                SDS_ILLUMINANTS["FL1"], method="NIST CQS 7.4"
+                SDS_ILLUMINANTS["FL1"], additional_data=False, method="NIST CQS 7.4"
             ),
             75.377089740493361,
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
         np.testing.assert_allclose(
-            colour_quality_scale(SDS_ILLUMINANTS["FL2"]),
+            colour_quality_scale(SDS_ILLUMINANTS["FL2"], additional_data=False),
             64.111822015662852,
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
         np.testing.assert_allclose(
             colour_quality_scale(
-                SDS_ILLUMINANTS["FL2"], method="NIST CQS 7.4"
+                SDS_ILLUMINANTS["FL2"], additional_data=False, method="NIST CQS 7.4"
             ),
             64.774586908581369,
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
         np.testing.assert_allclose(
-            colour_quality_scale(SDS_LIGHT_SOURCES["Neodimium Incandescent"]),
+            colour_quality_scale(
+                SDS_LIGHT_SOURCES["Neodimium Incandescent"], additional_data=False
+            ),
             89.737456186836681,
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
@@ -71,6 +69,7 @@ class TestColourQualityScale(unittest.TestCase):
         np.testing.assert_allclose(
             colour_quality_scale(
                 SDS_LIGHT_SOURCES["Neodimium Incandescent"],
+                additional_data=False,
                 method="NIST CQS 7.4",
             ),
             87.700300087538821,
@@ -79,7 +78,7 @@ class TestColourQualityScale(unittest.TestCase):
 
         np.testing.assert_allclose(
             colour_quality_scale(
-                SDS_LIGHT_SOURCES["F32T8/TL841 (Triphosphor)"]
+                SDS_LIGHT_SOURCES["F32T8/TL841 (Triphosphor)"], additional_data=False
             ),
             84.934928463428903,
             atol=TOLERANCE_ABSOLUTE_TESTS,
@@ -88,6 +87,7 @@ class TestColourQualityScale(unittest.TestCase):
         np.testing.assert_allclose(
             colour_quality_scale(
                 SDS_LIGHT_SOURCES["F32T8/TL841 (Triphosphor)"],
+                additional_data=False,
                 method="NIST CQS 7.4",
             ),
             83.255457439460713,
@@ -209,196 +209,190 @@ class TestColourQualityScale(unittest.TestCase):
                 ),
             },
             colorimetry_data=(
-                [
+                (
                     DataColorimetry_VS(
                         name="VS1",
                         XYZ=np.array([0.13183826, 0.09887241, 0.22510560]),
                         Lab=np.array([37.63929023, 27.59987425, -26.20530751]),
-                        C=38.058786112947161,
+                        C=np.array([38.058786112947161]),
                     ),
                     DataColorimetry_VS(
                         name="VS2",
                         XYZ=np.array([0.13061818, 0.10336027, 0.30741529]),
                         Lab=np.array([38.43888224, 23.35252921, -37.81858787]),
-                        C=44.447566961689617,
+                        C=np.array([44.447566961689617]),
                     ),
                     DataColorimetry_VS(
                         name="VS3",
                         XYZ=np.array([0.10089287, 0.09200351, 0.32265558]),
                         Lab=np.array([36.36721207, 11.00392324, -43.53144829]),
-                        C=44.900705083686788,
+                        C=np.array([44.900705083686788]),
                     ),
                     DataColorimetry_VS(
                         name="VS4",
                         XYZ=np.array([0.13339390, 0.15696027, 0.38421714]),
                         Lab=np.array([46.57313273, -9.89411460, -33.95550516]),
-                        C=35.367638235231176,
+                        C=np.array([35.367638235231176]),
                     ),
                     DataColorimetry_VS(
                         name="VS5",
                         XYZ=np.array([0.18662999, 0.24708620, 0.40043676]),
-                        Lab=np.array(
-                            [56.79040832, -23.15964295, -18.30798276]
-                        ),
-                        C=29.522047597875542,
+                        Lab=np.array([56.79040832, -23.15964295, -18.30798276]),
+                        C=np.array([29.522047597875542]),
                     ),
                     DataColorimetry_VS(
                         name="VS6",
                         XYZ=np.array([0.15843362, 0.24157338, 0.26933196]),
                         Lab=np.array([56.24498076, -36.24891195, -1.43946286]),
-                        C=36.277481597875926,
+                        C=np.array([36.277481597875926]),
                     ),
                     DataColorimetry_VS(
                         name="VS7",
                         XYZ=np.array([0.14991085, 0.24929718, 0.13823961]),
                         Lab=np.array([57.00687838, -44.55799945, 24.99093151]),
-                        C=51.087786926248803,
+                        C=np.array([51.087786926248803]),
                     ),
                     DataColorimetry_VS(
                         name="VS8",
                         XYZ=np.array([0.26141761, 0.36817692, 0.11429088]),
                         Lab=np.array([67.14003019, -33.22377274, 48.66064659]),
-                        C=58.920943658800866,
+                        C=np.array([58.920943658800866]),
                     ),
                     DataColorimetry_VS(
                         name="VS9",
                         XYZ=np.array([0.42410903, 0.52851922, 0.11439812]),
                         Lab=np.array([77.78749106, -22.21024952, 66.98873308]),
-                        C=70.5746806093467,
+                        C=np.array([70.5746806093467]),
                     ),
                     DataColorimetry_VS(
                         name="VS10",
                         XYZ=np.array([0.55367933, 0.62018757, 0.09672217]),
                         Lab=np.array([82.92339395, -8.84301088, 80.99721844]),
-                        C=81.478513954529475,
+                        C=np.array([81.478513954529475]),
                     ),
                     DataColorimetry_VS(
                         name="VS11",
                         XYZ=np.array([0.39755898, 0.39521027, 0.05739407]),
                         Lab=np.array([69.12701310, 6.97471851, 71.51095397]),
-                        C=71.850283480415115,
+                        C=np.array([71.850283480415115]),
                     ),
                     DataColorimetry_VS(
                         name="VS12",
                         XYZ=np.array([0.43757530, 0.38969458, 0.08630191]),
                         Lab=np.array([68.72913590, 20.83589132, 59.86354051]),
-                        C=63.385943630694335,
+                        C=np.array([63.385943630694335]),
                     ),
                     DataColorimetry_VS(
                         name="VS13",
                         XYZ=np.array([0.34657727, 0.27547744, 0.08900676]),
                         Lab=np.array([59.47793328, 31.84647528, 43.02166812]),
-                        C=53.526273138196274,
+                        C=np.array([53.526273138196274]),
                     ),
                     DataColorimetry_VS(
                         name="VS14",
                         XYZ=np.array([0.14271714, 0.09107438, 0.04949461]),
                         Lab=np.array([36.19033157, 40.77665898, 18.34813575]),
-                        C=44.714539058373845,
+                        C=np.array([44.714539058373845]),
                     ),
                     DataColorimetry_VS(
                         name="VS15",
                         XYZ=np.array([0.13593948, 0.09214669, 0.11591665]),
                         Lab=np.array([36.39436371, 35.62220213, -4.79596673]),
-                        C=35.94360278722214,
+                        C=np.array([35.94360278722214]),
                     ),
-                ],
-                [
+                ),
+                (
                     DataColorimetry_VS(
                         name="VS1",
                         XYZ=np.array([0.15205130, 0.10842697, 0.21629425]),
                         Lab=np.array([39.31425803, 32.98285941, -21.74818073]),
-                        C=39.507624328927392,
+                        C=np.array([39.507624328927392]),
                     ),
                     DataColorimetry_VS(
                         name="VS2",
                         XYZ=np.array([0.13187179, 0.10619377, 0.29945481]),
                         Lab=np.array([38.93186373, 22.05038057, -35.82206456]),
-                        C=42.064707208617435,
+                        C=np.array([42.064707208617435]),
                     ),
                     DataColorimetry_VS(
                         name="VS3",
                         XYZ=np.array([0.10123263, 0.09853741, 0.32956604]),
                         Lab=np.array([37.57864252, 6.04766746, -42.39139508]),
-                        C=42.82061020516246,
+                        C=np.array([42.82061020516246]),
                     ),
                     DataColorimetry_VS(
                         name="VS4",
                         XYZ=np.array([0.13144454, 0.16803553, 0.39315864]),
-                        Lab=np.array(
-                            [48.01155296, -17.36604069, -32.56734417]
-                        ),
-                        C=36.908146466038922,
+                        Lab=np.array([48.01155296, -17.36604069, -32.56734417]),
+                        C=np.array([36.908146466038922]),
                     ),
                     DataColorimetry_VS(
                         name="VS5",
                         XYZ=np.array([0.18145723, 0.25845953, 0.41319313]),
-                        Lab=np.array(
-                            [57.89053983, -30.61152779, -17.92233237]
-                        ),
-                        C=35.472181086008781,
+                        Lab=np.array([57.89053983, -30.61152779, -17.92233237]),
+                        C=np.array([35.472181086008781]),
                     ),
                     DataColorimetry_VS(
                         name="VS6",
                         XYZ=np.array([0.15184114, 0.25076481, 0.28160235]),
                         Lab=np.array([57.14986362, -44.01984887, -1.76443512]),
-                        C=44.055196354398468,
+                        C=np.array([44.055196354398468]),
                     ),
                     DataColorimetry_VS(
                         name="VS7",
                         XYZ=np.array([0.13956282, 0.25328776, 0.14470413]),
                         Lab=np.array([57.39436644, -52.59240053, 24.11037488]),
-                        C=57.8556027598421,
+                        C=np.array([57.8556027598421]),
                     ),
                     DataColorimetry_VS(
                         name="VS8",
                         XYZ=np.array([0.24672357, 0.36210726, 0.11976641]),
                         Lab=np.array([66.68062145, -37.45331629, 46.38001890]),
-                        C=59.614235332660144,
+                        C=np.array([59.614235332660144]),
                     ),
                     DataColorimetry_VS(
                         name="VS9",
                         XYZ=np.array([0.40820163, 0.50861708, 0.11894288]),
                         Lab=np.array([76.59516365, -21.90847578, 63.69499819]),
-                        C=67.357509638238682,
+                        C=np.array([67.357509638238682]),
                     ),
                     DataColorimetry_VS(
                         name="VS10",
                         XYZ=np.array([0.56036726, 0.60569219, 0.10169199]),
                         Lab=np.array([82.14661230, -3.82032735, 78.14954550]),
-                        C=78.24286780890229,
+                        C=np.array([78.24286780890229]),
                     ),
                     DataColorimetry_VS(
                         name="VS11",
                         XYZ=np.array([0.40540651, 0.38003446, 0.05753983]),
                         Lab=np.array([68.02315451, 14.17690044, 69.54409225]),
-                        C=70.974398718322206,
+                        C=np.array([70.974398718322206]),
                     ),
                     DataColorimetry_VS(
                         name="VS12",
                         XYZ=np.array([0.45407809, 0.37920609, 0.08621297]),
                         Lab=np.array([67.96206127, 28.93563884, 58.57062794]),
-                        C=65.328321974859804,
+                        C=np.array([65.328321974859804]),
                     ),
                     DataColorimetry_VS(
                         name="VS13",
                         XYZ=np.array([0.37207030, 0.27413935, 0.08882217]),
                         Lab=np.array([59.35552778, 40.92542311, 42.87088737]),
-                        C=59.268906188196901,
+                        C=np.array([59.268906188196901]),
                     ),
                     DataColorimetry_VS(
                         name="VS14",
                         XYZ=np.array([0.19307398, 0.11049957, 0.04883445]),
                         Lab=np.array([39.66448332, 53.96576475, 24.65796798]),
-                        C=59.332277465127156,
+                        C=np.array([59.332277465127156]),
                     ),
                     DataColorimetry_VS(
                         name="VS15",
                         XYZ=np.array([0.17306027, 0.10700056, 0.11280793]),
                         Lab=np.array([39.07062485, 45.99788526, 0.67641984]),
-                        C=46.002858517472262,
+                        C=np.array([46.002858517472262]),
                     ),
-                ],
+                ),
             ),
         )
 
@@ -407,14 +401,8 @@ class TestColourQualityScale(unittest.TestCase):
         )
 
         np.testing.assert_allclose(
-            [
-                data.Q_a
-                for _index, data in sorted(specification_r.Q_as.items())
-            ],
-            [
-                data.Q_a
-                for _index, data in sorted(specification_t.Q_as.items())
-            ],
+            [data.Q_a for _index, data in sorted(specification_r.Q_as.items())],
+            [data.Q_a for _index, data in sorted(specification_t.Q_as.items())],
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
 
@@ -533,196 +521,190 @@ class TestColourQualityScale(unittest.TestCase):
                 ),
             },
             colorimetry_data=(
-                [
+                (
                     DataColorimetry_VS(
                         name="VS1",
                         XYZ=np.array([0.14271715, 0.09107438, 0.04949462]),
                         Lab=np.array([36.19033159, 40.77666015, 18.34813122]),
-                        C=44.714538268056295,
+                        C=np.array([44.714538268056295]),
                     ),
                     DataColorimetry_VS(
                         name="VS2",
                         XYZ=np.array([0.34657727, 0.27547744, 0.08900676]),
                         Lab=np.array([59.47793328, 31.84647553, 43.02166698]),
-                        C=53.526272364542265,
+                        C=np.array([53.526272364542265]),
                     ),
                     DataColorimetry_VS(
                         name="VS3",
                         XYZ=np.array([0.41050103, 0.38688447, 0.06613576]),
                         Lab=np.array([68.52498199, 13.58373774, 66.83110597]),
-                        C=68.197614738277153,
+                        C=np.array([68.197614738277153]),
                     ),
                     DataColorimetry_VS(
                         name="VS4",
                         XYZ=np.array([0.45427132, 0.50401485, 0.08193287]),
                         Lab=np.array([76.31503360, -7.01311937, 74.42292542]),
-                        C=74.752629859451574,
+                        C=np.array([74.752629859451574]),
                     ),
                     DataColorimetry_VS(
                         name="VS5",
                         XYZ=np.array([0.42410903, 0.52851922, 0.11439811]),
                         Lab=np.array([77.78749106, -22.21024992, 66.98873490]),
-                        C=70.574682470722237,
+                        C=np.array([70.574682470722237]),
                     ),
                     DataColorimetry_VS(
                         name="VS6",
                         XYZ=np.array([0.26141761, 0.36817692, 0.11429088]),
                         Lab=np.array([67.14003019, -33.22377278, 48.66064673]),
-                        C=58.920943801328043,
+                        C=np.array([58.920943801328043]),
                     ),
                     DataColorimetry_VS(
                         name="VS7",
                         XYZ=np.array([0.14991085, 0.24929718, 0.13823960]),
                         Lab=np.array([57.00687837, -44.55800078, 24.99093412]),
-                        C=51.087789364109447,
+                        C=np.array([51.087789364109447]),
                     ),
                     DataColorimetry_VS(
                         name="VS8",
                         XYZ=np.array([0.15843361, 0.24157338, 0.26933192]),
                         Lab=np.array([56.24498073, -36.24891645, -1.43945699]),
-                        C=36.277485856650493,
+                        C=np.array([36.277485856650493]),
                     ),
                     DataColorimetry_VS(
                         name="VS9",
                         XYZ=np.array([0.18662998, 0.24708620, 0.40043672]),
-                        Lab=np.array(
-                            [56.79040828, -23.15964795, -18.30797717]
-                        ),
-                        C=29.522048055967336,
+                        Lab=np.array([56.79040828, -23.15964795, -18.30797717]),
+                        C=np.array([29.522048055967336]),
                     ),
                     DataColorimetry_VS(
                         name="VS10",
                         XYZ=np.array([0.13339389, 0.15696027, 0.38421709]),
                         Lab=np.array([46.57313267, -9.89412218, -33.95549821]),
-                        C=35.367633681665495,
+                        C=np.array([35.367633681665495]),
                     ),
                     DataColorimetry_VS(
                         name="VS11",
                         XYZ=np.array([0.09900743, 0.09954465, 0.32039098]),
                         Lab=np.array([37.76058147, 3.51413565, -40.81527590]),
-                        C=40.966277550944625,
+                        C=np.array([40.966277550944625]),
                     ),
                     DataColorimetry_VS(
                         name="VS12",
                         XYZ=np.array([0.11576390, 0.09613722, 0.31928926]),
                         Lab=np.array([37.14003664, 18.77460935, -41.73197608]),
-                        C=45.760723157938472,
+                        C=np.array([45.760723157938472]),
                     ),
                     DataColorimetry_VS(
                         name="VS13",
                         XYZ=np.array([0.20975356, 0.16847879, 0.37267453]),
                         Lab=np.array([48.06778877, 25.97523691, -29.94366223]),
-                        C=39.640078711661452,
+                        C=np.array([39.640078711661452]),
                     ),
                     DataColorimetry_VS(
                         name="VS14",
                         XYZ=np.array([0.32298108, 0.24163045, 0.36212750]),
                         Lab=np.array([56.25066973, 37.45976513, -14.49801776]),
-                        C=40.167480906459893,
+                        C=np.array([40.167480906459893]),
                     ),
                     DataColorimetry_VS(
                         name="VS15",
                         XYZ=np.array([0.22039693, 0.15371392, 0.17553541]),
                         Lab=np.array([46.13873255, 39.31630210, -2.10769974]),
-                        C=39.372757193029329,
+                        C=np.array([39.372757193029329]),
                     ),
-                ],
-                [
+                ),
+                (
                     DataColorimetry_VS(
                         name="VS1",
                         XYZ=np.array([0.19307399, 0.11049957, 0.04883449]),
                         Lab=np.array([39.66448335, 53.96576813, 24.65795205]),
-                        C=59.332273930950407,
+                        C=np.array([59.332273930950407]),
                     ),
                     DataColorimetry_VS(
                         name="VS2",
                         XYZ=np.array([0.37207030, 0.27413935, 0.08882218]),
                         Lab=np.array([59.35552779, 40.92542394, 42.87088336]),
-                        C=59.268903858924929,
+                        C=np.array([59.268903858924929]),
                     ),
                     DataColorimetry_VS(
                         name="VS3",
                         XYZ=np.array([0.42080177, 0.37272049, 0.06618662]),
                         Lab=np.array([67.48063529, 21.22017785, 65.01028998]),
-                        C=68.385917784001094,
+                        C=np.array([68.385917784001094]),
                     ),
                     DataColorimetry_VS(
                         name="VS4",
                         XYZ=np.array([0.46201298, 0.49481812, 0.08588402]),
                         Lab=np.array([75.75009449, -2.36998858, 72.10803500]),
-                        C=72.146971918467017,
+                        C=np.array([72.146971918467017]),
                     ),
                     DataColorimetry_VS(
                         name="VS5",
                         XYZ=np.array([0.40820163, 0.50861708, 0.11894286]),
                         Lab=np.array([76.59516364, -21.90847694, 63.69500310]),
-                        C=67.35751466170575,
+                        C=np.array([67.35751466170575]),
                     ),
                     DataColorimetry_VS(
                         name="VS6",
                         XYZ=np.array([0.24672357, 0.36210726, 0.11976641]),
                         Lab=np.array([66.68062144, -37.45331655, 46.38001966]),
-                        C=59.614236088535129,
+                        C=np.array([59.614236088535129]),
                     ),
                     DataColorimetry_VS(
                         name="VS7",
                         XYZ=np.array([0.13956281, 0.25328776, 0.14470409]),
                         Lab=np.array([57.39436642, -52.59240564, 24.11038403]),
-                        C=57.855611215555271,
+                        C=np.array([57.855611215555271]),
                     ),
                     DataColorimetry_VS(
                         name="VS8",
                         XYZ=np.array([0.15184111, 0.25076481, 0.28160222]),
                         Lab=np.array([57.14986354, -44.01986548, -1.76441495]),
-                        C=44.055212144295837,
+                        C=np.array([44.055212144295837]),
                     ),
                     DataColorimetry_VS(
                         name="VS9",
                         XYZ=np.array([0.18145720, 0.25845953, 0.41319296]),
-                        Lab=np.array(
-                            [57.89053974, -30.61154597, -17.92231311]
-                        ),
-                        C=35.472187042106164,
+                        Lab=np.array([57.89053974, -30.61154597, -17.92231311]),
+                        C=np.array([35.472187042106164]),
                     ),
                     DataColorimetry_VS(
                         name="VS10",
                         XYZ=np.array([0.13144449, 0.16803553, 0.39315843]),
-                        Lab=np.array(
-                            [48.01155280, -17.36606803, -32.56732004]
-                        ),
-                        C=36.908138035180549,
+                        Lab=np.array([48.01155280, -17.36606803, -32.56732004]),
+                        C=np.array([36.908138035180549]),
                     ),
                     DataColorimetry_VS(
                         name="VS11",
                         XYZ=np.array([0.09725029, 0.10655822, 0.32331756]),
                         Lab=np.array([38.99463289, -3.20501320, -39.09286753]),
-                        C=39.224028364277721,
+                        C=np.array([39.224028364277721]),
                     ),
                     DataColorimetry_VS(
                         name="VS12",
                         XYZ=np.array([0.11497971, 0.09965866, 0.31509326]),
                         Lab=np.array([37.78109906, 15.45054732, -40.03995920]),
-                        C=42.917569190579727,
+                        C=np.array([42.917569190579727]),
                     ),
                     DataColorimetry_VS(
                         name="VS13",
                         XYZ=np.array([0.23125767, 0.17972670, 0.36038776]),
                         Lab=np.array([49.46294201, 29.95248104, -25.97793559]),
-                        C=39.648508903390763,
+                        C=np.array([39.648508903390763]),
                     ),
                     DataColorimetry_VS(
                         name="VS14",
                         XYZ=np.array([0.35887695, 0.25609884, 0.35518732]),
                         Lab=np.array([57.66488716, 43.83765559, -11.16556087]),
-                        C=45.237261162848789,
+                        C=np.array([45.237261162848789]),
                     ),
                     DataColorimetry_VS(
                         name="VS15",
                         XYZ=np.array([0.26552457, 0.17192965, 0.17300682]),
                         Lab=np.array([48.50225789, 48.80528996, 2.49443403]),
-                        C=48.868993532230895,
+                        C=np.array([48.868993532230895]),
                     ),
-                ],
+                ),
             ),
         )
 
@@ -731,17 +713,7 @@ class TestColourQualityScale(unittest.TestCase):
         )
 
         np.testing.assert_allclose(
-            [
-                data.Q_a
-                for _index, data in sorted(specification_r.Q_as.items())
-            ],
-            [
-                data.Q_a
-                for _index, data in sorted(specification_t.Q_as.items())
-            ],
+            [data.Q_a for _index, data in sorted(specification_r.Q_as.items())],
+            [data.Q_a for _index, data in sorted(specification_t.Q_as.items())],
             atol=TOLERANCE_ABSOLUTE_TESTS,
         )
-
-
-if __name__ == "__main__":
-    unittest.main()
